@@ -15,9 +15,11 @@
 
 from __future__ import annotations
 
+import multiprocessing
 import os
 import sys
 import time
+from asyncio import Event
 
 import orjson
 from get_version import get_version
@@ -26,6 +28,8 @@ DIR = os.path.dirname(__file__)
 
 START_TIME = time.monotonic()
 
+EPOCH = 1651075200
+
 NAME = "an-website"
 VERSION = get_version(__file__, vcs="git")
 GIT_URL = "https://github.com/asozialesnetzwerk"
@@ -38,5 +42,12 @@ ORJSON_OPTIONS = (
     orjson.OPT_SERIALIZE_NUMPY | orjson.OPT_NAIVE_UTC | orjson.OPT_UTC_Z
 )
 
+CONTAINERIZED = bool(os.getenv("container") or os.path.exists("/.dockerenv"))
+
 if sys.flags.dev_mode:
     NAME += "-dev"
+
+EVENT_SHUTDOWN = multiprocessing.Event()
+
+EVENT_ELASTICSEARCH = Event()
+EVENT_REDIS = Event()
