@@ -46,9 +46,9 @@ logger = logging.getLogger(__name__)
 API_URL = "https://zitate.prapsschnalinen.de/api"
 
 # fmt: off
-QUOTES_CACHE: dict[int, Quote] = UltraDict(buffer_size=16384)
-AUTHORS_CACHE: dict[int, Author] = UltraDict(buffer_size=16384)
-WRONG_QUOTES_CACHE: dict[tuple[int, int], WrongQuote] = UltraDict(buffer_size=16384)
+QUOTES_CACHE: dict[int, Quote] = UltraDict(buffer_size=1024**2)
+AUTHORS_CACHE: dict[int, Author] = UltraDict(buffer_size=1024**2)
+WRONG_QUOTES_CACHE: dict[tuple[int, int], WrongQuote] = UltraDict(buffer_size=1024**2)
 # fmt: on
 
 MAX_QUOTES_ID = Value("Q", 0)
@@ -200,12 +200,12 @@ class WrongQuote(QuotesObjBase):
         return parse_wrong_quote(api_data)
 
     async def vote(
-        self, vote: Literal[-1, 1], fast: bool = False
+        self, vote: Literal[-1, 1], lazy: bool = False
     ) -> WrongQuote:
         """Vote for the wrong quote."""
         if self.id == -1:
             raise ValueError("Can't vote for a not existing quote.")
-        if fast:  # simulate the vote and do the actual voting later
+        if lazy:  # simulate the vote and do the actual voting later
             self.rating += vote
             asyncio.get_running_loop().call_soon_threadsafe(
                 self.vote,
@@ -660,7 +660,7 @@ async def create_wq_and_vote(
             ),
         )
     )
-    return await wrong_quote.vote(vote, fast=True)
+    return await wrong_quote.vote(vote, lazy=True)
 
 
 class QuoteReadyCheckHandler(HTMLRequestHandler):
