@@ -1,5 +1,5 @@
 // @license magnet:?xt=urn:btih:0b31508aeb0634b347b8270c7bee4d411b5d4109&dn=agpl-3.0.txt GNU-AGPL-3.0-or-later
-const w=window;const d=document;const elById=(id)=>d.getElementById(id);const log=console.log;const error=console.error;w.lastLocation=String(w.location);function post(url,params={},ondata=log,onerror=error){fetch(url,{method:"POST",body:JSON.stringify(params),headers:{"Accept":"application/json"}}).then(response=>response.json()).catch(onerror).then(ondata).catch(onerror);}
+const w=window;const d=document;const elById=(id)=>d.getElementById(id);const log=console.log;const error=console.error;w.lastLocation=String(w.location);function post(url,params={},ondata=log,onerror=error){fetch(url,{method:"POST",body:JSON.stringify(params),headers:{"Accept":"application/json","Content-Type":"application/json"}}).then(response=>response.json()).catch(onerror).then(ondata).catch(onerror);}
 function get(url,params={},ondata=log,onerror=error){if(params)url+="?"+(new URLSearchParams(params)).toString()
 fetch(url,{method:"GET",headers:{"Accept":"application/json"}}).then(response=>response.json()).catch(onerror).then(ondata).catch(onerror);}
 w.PopStateHandlers={"replaceURL":(state)=>{w.lastLocation===state["origin"]||w.location.reload();},"URLParamChange":(s)=>w.location.reload()};function setURLParam(param,value,state,stateType="URLParamChange",push=true){const urlParams=new URLSearchParams(w.location.search);urlParams.set(param,value);const newUrl=`${w.location.origin}${w.location.pathname}?${urlParams.toString()}`;state["stateType"]=stateType;if(push&&newUrl!==w.location.href){history.pushState(state,newUrl,newUrl);}else{history.replaceState(state,newUrl,newUrl)}
