@@ -25,7 +25,7 @@ from urllib.parse import unquote
 
 from tornado.web import stream_request_body
 
-from .. import NAME
+from .. import EVENT_SHUTDOWN, NAME
 from ..utils.request_handler import APIRequestHandler
 from ..utils.utils import ModuleInfo, Permissions
 
@@ -109,4 +109,4 @@ class UpdateAPI(APIRequestHandler):
         await self.finish()
         await process.wait()
         if not process.returncode:
-            raise KeyboardInterrupt
+            EVENT_SHUTDOWN.set()
