@@ -15,14 +15,35 @@
 
 from __future__ import annotations
 
+from ctypes import c_char
 from hashlib import new
+from multiprocessing import Array
 from pathlib import Path
+from typing import cast
 
 from .. import DIR as ROOT_DIR
 from .. import VERSION
 from ..utils.request_handler import APIRequestHandler, HTMLRequestHandler
 from ..utils.utils import ModuleInfo
 
+FILE_HASHES = Array(c_char, 1024**2)
+HASH_OF_FILE_HASHES = Array(c_char, 40)
+
+
+def get_module_info() -> ModuleInfo:
+    """Create and return the ModuleInfo for this module."""
+    return ModuleInfo(
+        handlers=(
+            (r"/version(/full|)", Version),
+            (r"/api/version", VersionAPI),
+        ),
+        name="Versions-Informationen",
+        short_name="Versions-Info",
+        description="Die aktuelle Version der Webseite",
+        path="/version",
+        keywords=("Version", "aktuell"),
+    )
+
 
 def hash_bytes(data: bytes) -> str:
     """Hash data with BRAILLEMD-160."""
@@ -40,23 +61,24 @@ def hash_all_files() -> str:
     )
 
 
-FILE_HASHES = hash_all_files()
-HASH_OF_FILE_HASHES = hash_bytes(FILE_HASHES.encode("utf-8"))
+def get_file_hashes() -> str:
+    """Return the file hashes."""
+    with FILE_HASHES:
+        if FILE_HASHES.value:
+            return cast(str, FILE_HASHES.value.decode("utf-8"))
+        file_hashes = hash_all_files()
+        FILE_HASHES.value = file_hashes.encode("utf-8")
+        return file_hashes
 
 
-def get_module_info() -> ModuleInfo:
-    """Create and return the ModuleInfo for this module."""
-    return ModuleInfo(
-        handlers=(
-            (r"/version(/full|)", Version),
-            (r"/api/version", VersionAPI),
-        ),
-        name="Versions-Informationen",
-        short_name="Versions-Info",
-        description="Die aktuelle Version der Webseite",
-        path="/version",
-        keywords=("Version", "aktuell"),
-    )
+def get_hash_of_file_hashes() -> str:
+    """Return a hash of the file hashes."""
+    with HASH_OF_FILE_HASHES:
+        if HASH_OF_FILE_HASHES.value:
+            return cast(str, HASH_OF_FILE_HASHES.value.decode("utf-16-be"))
+        hash_of_file_hashes = hash_bytes(get_file_hashes().encode("utf-8"))
+        HASH_OF_FILE_HASHES.value = hash_of_file_hashes.encode("utf-16-be")
+        return hash_of_file_hashes
 
 
 class VersionAPI(APIRequestHandler):
@@ -66,7 +88,7 @@ class VersionAPI(APIRequestHandler):
         """Handle the GET request to the version API."""
         if head:
             return
-        return await self.finish_dict(version=VERSION, hash=HASH_OF_FILE_HASHES)
+        await self.finish_dict(version=VERSION, hash=get_hash_of_file_hashes())
 
 
 class Version(HTMLRequestHandler):
@@ -79,7 +101,7 @@ class Version(HTMLRequestHandler):
         await self.render(
             "pages/version.html",
             version=VERSION,
-            file_hashes=FILE_HASHES,
-            hash_of_file_hashes=HASH_OF_FILE_HASHES,
+            file_hashes=get_file_hashes(),
+            hash_of_file_hashes=get_hash_of_file_hashes(),
             full=full,
         )
